# jurt: Jeff's Unified Registration Tool

Facilitate coregistration and spatial normalization of fMRI datasets.

# License

Copyright (c) 2018, Jeffrey M. Engelmann

`jurt` is released under the revised (3-clause) BSD license.
For details, see [LICENSE.txt](LICENSE.txt).

